.. _glm:

=========================
Analyzing fMRI using GLMs
=========================

Nilearn's stats module uses Generalized Linear Model to analyze functional MRI data. Nilearn
offers functions to set up first- and second-level models, perform t-tests, multiple-comparisons
correction and thresholding, and allows for the generation of html reports that detail the
analyses performed and present thresholded results.


.. toctree::

   glm_intro.rst
   first_level_model.rst
   second_level_model.rst
   meaning_difference.rst
